@@ -18,14 +18,20 @@ if [ ! -d "mate-desktop" ]; then
   git clone https://github.com/mate-desktop/mate-desktop.git
 fi
 cat << EOF > $OUTPUT
-  <sect1 id="mate-dconf-list">
-    <title>List of Dconf Keys of MATE Desktop</title>
+<?xml version="1.0" encoding="utf-8"?>
+<?db.chunk.max_depth 3?>
+<section xmlns="http://docbook.org/ns/docbook"
+         xmlns:db="http://docbook.org/ns/docbook"
+         xmlns:xlink="http://www.w3.org/1999/xlink"
+         xmlns:its="http://www.w3.org/2005/11/its"
+         version="5.0" its:version="2.0" xml:id="mate-dconf-list" xml:lang="en">
+    <info><title>List of Dconf Keys of MATE Desktop</title></info>
 EOF
 for file in mate-desktop/schemas/*.gschema.xml.in; do
   xsltproc gosdconfkeys.xsl $file >> $OUTPUT
 done
 cat << EOF >> $OUTPUT
-  </sect1>
+  </section>
 EOF
 xmllint -format $OUTPUT > $OUTPUT.aux
 mv $OUTPUT.aux $OUTPUT
